# RPG
Pacote Python com as minhas ferramentas de RPG

- **2.2.2** - Inclusão de valor do ataque do ataque atual como propriedade em PF2
- **2.2.1** - Correção no cálculo de save do PF2
- **2.2.0** - Inclusão do submódulo de pf2
- **2.1.2** - Correção na representação de dado
- **2.1.0** - Correção de bug
- **2.0.0** - Alteração na classe Baralho
- **1.0.0** - Lançamento